```
Usage: vcd gateway services ipsec-vpn change-shared-key [OPTIONS] <gateway
                                                        name> <new shared key>

Options:
  -h, --help  Show this message and exit.

```
